asr.setup.strains
=================

.. automodule:: asr.setup.strains

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_relevant_strains
   .. autofunction:: get_strained_folder_name
   .. autofunction:: setup_strains
   
   

   
   
   

   
   
   